@@ -36,6 +36,11 @@ def Retrive_FirstLevel(start_date, end_date, period, jsonLocation, tbColumn, dbT
             except IndexError:
                 print("Index Error")
                 continue
+
+            except AttributeError:
+                print("Attribute Error")
+                continue
+
             
             break
 
@@ -67,6 +72,10 @@ def Retrive_SecondLevel(start_date, end_date, period, jsonLocation, jsonLocation
             except IndexError:
                 print("Index Error")
                 continue
+
+            except AttributeError:
+                print("Attribute Error")
+                continue
             
             break
 
@@ -93,6 +102,10 @@ def Retrive_by_RS(start_date, end_date, period, jsonLocation, rsInput, tbColumn,
                 print("Index Error")
                 continue
 
+            except AttributeError:
+                print("Attribute Error")
+                continue
+
             stackTodb(sample, dbTableName)
 
 ## 22.04.30 added
@@ -120,4 +133,8 @@ def Retrive_by_RS_breakdown(start_date, end_date, period, jsonLocation, jsonLoca
                 print("Index Error")
                 continue
 
+            except AttributeError:
+                print("Attribute Error")
+                continue
+
             stackTodb(sample, dbTableName)
